@@ -18,6 +18,7 @@
 ml_fpgrowth <- function(x, items_col = "items", min_confidence = 0.8,
                         min_support = 0.3, prediction_col = "prediction",
                         uid = random_string("fpgrowth_"), ...) {
+  check_dots_used()
   UseMethod("ml_fpgrowth")
 }
 
@@ -33,7 +34,7 @@ ml_fpgrowth.spark_connection <- function(x, items_col = "items", min_confidence
     prediction_col = prediction_col
   ) %>%
     c(rlang::dots_list(...)) %>%
-    ml_validator_fpgrowth()
+    validator_ml_fpgrowth()
 
   uid <- cast_string(uid)
   jobj <- invoke_new(x, "org.apache.spark.ml.fpm.FPGrowth", uid) %>%
@@ -80,7 +81,7 @@ ml_fpgrowth.tbl_spark <- function(x, items_col = "items", min_confidence = 0.8,
 }
 
 # Validator
-ml_validator_fpgrowth <- function(.args) {
+validator_ml_fpgrowth <- function(.args) {
   .args[["items_col"]] <- cast_string(.args[["items_col"]])
   .args[["min_confidence"]] <- cast_scalar_double(.args[["min_confidence"]])
   .args[["min_support"]] <- cast_scalar_double(.args[["min_support"]])
@@ -89,7 +90,7 @@ ml_validator_fpgrowth <- function(.args) {
 }
 
 new_ml_fpgrowth <- function(jobj) {
-  new_ml_predictor(jobj, subclass = "ml_fpgrowth")
+  new_ml_estimator(jobj, class = "ml_fpgrowth")
 }
 
 new_ml_fpgrowth_model <- function(jobj) {
@@ -100,7 +101,7 @@ new_ml_fpgrowth_model <- function(jobj) {
       sdf_register(),
     freq_itemsets = invoke(jobj, "freqItemsets") %>%
       sdf_register(),
-    subclass = "ml_fpgrowth_model")
+    class = "ml_fpgrowth_model")
 }
 
 #' @rdname ml_fpgrowth
