@@ -1,28 +1,5 @@
-spark_yarn_cluster_get_conf_property <- function(property) {
-  confDir <- Sys.getenv("YARN_CONF_DIR")
-  if (nchar(confDir) == 0) {
-
-    # some systems don't set YARN_CONF_DIR but do set HADOOP_CONF_DIR
-    confDir <- Sys.getenv("HADOOP_CONF_DIR")
-    if (nchar(confDir) == 0) {
-      stop("Yarn Cluster mode requires YARN_CONF_DIR or HADOOP_CONF_DIR to be set.")
-    }
-  }
-
-  yarnSite <- file.path(confDir, "yarn-site.xml")
-  if (!file.exists(yarnSite)) {
-    stop("Yarn Cluster mode requires yarn-site.xml to exist under YARN_CONF_DIR")
-  }
-
-  yarnSiteXml <- xml2::read_xml(yarnSite)
-
-  yarnPropertyValue <- xml2::xml_text(xml2::xml_find_all(
-    yarnSiteXml,
-    paste0("//name[.='", property, "']/parent::property/value")
-  )
-  )
-
-  yarnPropertyValue
+spark_yarn_cluster_get_conf_property <- function(scon) {
+  spark_yarn_get_conf_property(scon)
 }
 
 spark_yarn_cluster_get_app_id <- function(config, start_time, rm_webapp) {
