@@ -61,6 +61,8 @@ class Backend() {
   private[this] var isWorker: Boolean = false
   private[this] var isBatch: Boolean = false
 
+  private[this] var args: Array[String] = Array[String]()
+
   private[this] var hostContext: String = null
 
   private[this] var isRunning: Boolean = true
@@ -106,6 +108,10 @@ class Backend() {
     sc = nsc
   }
 
+  def setArgs(argsParam: Array[String]): Unit = {
+    args = argsParam
+  }
+
   def setType(isServiceParam: Boolean,
               isRemoteParam: Boolean,
               isWorkerParam: Boolean,
@@ -240,7 +246,7 @@ class Backend() {
           val options: Map[String, String] = Map()
 
           rscript.init(
-            List(),
+            args.toList,
             modifiedFile.getAbsolutePath(),
             customEnv,
             options
