@@ -3,7 +3,7 @@ context("copy data")
 sc <- testthat_spark_connection()
 
 test_that("sdf_copy_to works for default serializer", {
-  df <- matrix(0, ncol = 5, nrow = 2) %>% dplyr::as_data_frame()
+  df <- matrix(0, ncol = 5, nrow = 2) %>% dplyr::as_tibble()
   df_tbl <- sdf_copy_to(sc, df, overwrite = TRUE)
 
   expect_equal(
@@ -15,7 +15,7 @@ test_that("sdf_copy_to works for default serializer", {
 test_that("sdf_copy_to works for scala serializer", {
   skip_livy()
 
-  df <- matrix(0, ncol = 5, nrow = 2) %>% dplyr::as_data_frame()
+  df <- matrix(0, ncol = 5, nrow = 2) %>% dplyr::as_tibble()
   df_tbl <- sdf_copy_to(sc, df, overwrite = TRUE, serializer = "csv_file_scala")
 
   expect_equal(
@@ -27,7 +27,7 @@ test_that("sdf_copy_to works for scala serializer", {
 test_that("sdf_copy_to works for csv serializer", {
   skip_livy()
 
-  df <- matrix(0, ncol = 5, nrow = 2) %>% dplyr::as_data_frame()
+  df <- matrix(0, ncol = 5, nrow = 2) %>% dplyr::as_tibble()
   df_tbl <- sdf_copy_to(sc, df, overwrite = TRUE, serializer = "csv_file")
 
   expect_equal(
@@ -47,7 +47,7 @@ test_that("spark_table_name() doesn't warn for multiline expression (#1386)", {
 })
 
 test_that("sdf_copy_to supports list of callbacks", {
-  df <- matrix(0, ncol = 5, nrow = 2) %>% dplyr::as_data_frame()
+  df <- matrix(0, ncol = 5, nrow = 2) %>% dplyr::as_tibble()
   df_tbl <- sdf_copy_to(sc, list(~df, ~df), overwrite = TRUE)
 
   expect_equal(
